@@ -1,6 +1,6 @@
-__version__ = "20220609.1"
+__version__ = "20220725.1"
 
 from .base import DAL
-from .objects import Field
 from .helpers.classes import SQLCustomType
-from .helpers.methods import geoPoint, geoLine, geoPolygon
+from .helpers.methods import geoLine, geoPoint, geoPolygon
+from .objects import Field
